@@ -1,5 +1,5 @@
 package HTTP::Thin::UserAgent;
-$HTTP::Thin::UserAgent::VERSION = '0.009';
+$HTTP::Thin::UserAgent::VERSION = '0.010';
 use 5.12.1;
 use warnings;
 
@@ -7,7 +7,7 @@ use warnings;
 
 {
 
-    package 
+    package
         HTTP::Thin::UserAgent::Client;
 
     use Moo;
@@ -15,7 +15,8 @@ use warnings;
     use HTTP::Thin;
     use JSON::Any;
     use Try::Tiny;
-    
+    use Scalar::Util qw/weaken/;
+
     use constant TRACE => $ENV{TRACE} // 0;
 
     use Throwable::Factory
@@ -58,7 +59,7 @@ use warnings;
         my $request = $self->request;
 
         return $ua->request($request) unless TRACE;
-            
+
         warn $request->dump;
         my $response = $ua->request($request);
         warn $response->dump;
@@ -66,7 +67,8 @@ use warnings;
     }
 
     sub as_json {
-        my $self    = shift;
+        my $self = shift;
+
         my $request = $self->request;
 
         $request->header(
@@ -80,6 +82,7 @@ use warnings;
 
         $self->decoder(
             sub {
+                weaken($self);
                 my $res          = shift;
                 my $content_type = $res->header('Content-Type');
                 unless ( $content_type =~ m'application/json' ) {
@@ -106,6 +109,7 @@ use warnings;
 
         $self->decoder(
             sub {
+                weaken($self);
                 my $res = shift;
                 my $data = try { $scraper->scrape( $res->decoded_content ) }
                 catch {
@@ -177,7 +181,7 @@ HTTP::Thin::UserAgent - A Thin UserAgent around some useful modules.
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -208,7 +212,7 @@ C<HTTP::Thin::UserAgent> provides what I hope is a thin layer over L<HTTP::Thin>
 
 A function that returns a new C<HTTP::Thin::UserAgent::Client> object, which does the actual work for the request. You pas in an L<HTTP::Request> object.
 
-=item GET / PUT / POST 
+=item GET / PUT / POST
 
 Exports from L<HTTP::Request::Common> to make generating L<HTTP::Request> objects easier.
 
@@ -242,9 +246,9 @@ Returns the decoded content, currently we only support HTML (in which case we re
 
 =item tree( )
 
-Returns a L<HTML::Treebuilder::XPath> object. 
+Returns a L<HTML::Treebuilder::XPath> object.
 
-=item find( $exp ) 
+=item find( $exp )
 
 Takes a CSS or XPath expression and returns an arrayref of L<HTML::Treebuilder::XPath> nodes.
 
